CosinorSpan_DateF_PeriVsCosFiltH2test <-
function (TimeCol=1,Y=2, window="none", RefDateTime="0",  timeFormat="%Y%m%d%H%M", RangeDateTime=list(Start=0, End=0), Units='Hour', dt=0, Progressive=list(Span=144, Increment=8), Period=list(Set=0,Start=0,Increment=1,End=0),header=F, Colors="BW",Graphics="pdf",Output=list(Txt=F,TxtAmp=F,Doc=T,HeatMap=T,LineGraphs=F),Console=F,Debug=FALSE,call=FALSE) {
  # Header:  T/F to indicate if the file has a header
  #%H represents 0-23, so have to have numeric time in Excel sheet, and numeric time rep option
  # Dates are represented as the number of days since 1970-01-01
  #strptime reads in characters and produces POSIX formatted date/time;  strptime accepts the format of date being read -- output is always POSIX
  #use format wrapped around POSIX to output a date in a different format than POSIX
  #POSIXct: This class stores a date in a vector, as the number of seconds passed since January, 1st, 1970 at 1AM
  #POSIXlt: This class stores a date in a list: (day of the month, day of the week, day of the year, month, year, time zone, hour, minute, second).
  # timeFormat:  program should read in the users's date format, and convert datetime in file to a standard format
  # TimeCol:  Column where time is found
  # Y:  Data to be analyzed
  # window:      Data will be convolved with a window:  hanning, hamming, bartlett, blackman.  Default="none"
  # RefDateTime:  Date used as reference, and subtracted from all data dates, to make the number smaller.  **Must be in the same time zone!!!!!**
  #             if RefDateTime = 0, use the 1st date of the data as the RefDateTime 
  #             if RefDateTime = 12, use midnight of the same day as the data starts 
  # timeFormat:   RefDateTime and the time in the data file should both use the same date/time format.  List it here
  #             if = "numeric", time column in data file can be simple numbers (0 - 99999...)
  # RangeDateTime
  #      $Start:  Analysis is started at this date/time.  May be before 1st data date.
  #             if Start = 0, use the 1st time in the data set
  #             if Start = 12 use Midnight at the start of the 1st date of the data as the StartDate 
  #        $End:    Analysis ends at this date/time.  May be after last data date.
  #             if End = 0, use the last time in the data set
  #             if End = 12 use the midnight at the end of the last date of the data as the EndDate   
  # Units:        Units (Hour, Year, Week or Day) for Span and Increment arguments, as well as Period arguments
  # Progressive
  #      $Span : number of Days, Wks or Yrs in a subset of full data  -- multiple spans calculated
  #               If 0, assumes no progession, Span is set to the full dataset length, and Increment = full data set  
  #  $Increment: number of Days, Wks or Yrs  (uses same unit as set for Span) to shift between span analyses
  #               If 0, assumes no progession, Span is set to the full dataset length, and Increment = full data set 
  # Period
  #       $End : Last (and smallest) period to calculate, in units of Days, Wks or Yrs (as set by Units)
  #               Defaults to 2;  (1 is too small) 0 is invalid  -- says use default
  #  $Increment : Increment to starting period, in units of Days, Wks or Yrs (as set by Units)
  #               Defaults to 1;   0 is invalid  -- says use default
  #     $Start : First (and largest) period to calculate, in units of Days, Wks or Yrs (as set by Units);  (Span/1)
  #               0 is Default: full time range analyzed [in hours?] (RangeDateTime$End-RangeDateTime$Start)= MyData_length; or if progressive, Span/1;     
  #      $Set :  Overrides Period$Start and $Increment, to specify a specific set of periods to analyze (as set by Units).  If $End will determine ending period 
  #              Can be in the format of a single number, or an array:  c(1,2,3) or c(8,12:24)
  #              If 0, a series of periods are analyzed (spectrum) according to Period$Start, $Increment, $End (or their default value, if not specified)
  #              When 0, only the maximum period, or the maximum period per span, from a spectrum is displayed on the graphics file.
  #              Otherwise, all periods are displayed on the graphic 
  #  Colors       "Heat" renders the heat map in colors;  "BW" renders the heatmap in grayscale
  #  Output      Txt will generate a comma delimited .txt document containing output,Doc will generate a nicely formatted Word doc
  #                  HeatMap will generate a heatmap, but only when more than one period is specified for a progressive analysis
  #                 LineGraphs will generate a set of graphs plotting MESOR, Amplitude, Acrophase over time--too many when you do a progressive
  # dt           When equidistant data, dt indicates the sampling interval.  If dt =0, no periodogram is done.
  #                  Data is assumed to be equidistant when this is nonzero
#   source('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions/CatPeri/CatPeri.R')    #  Add for MAC
#   source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Cosinor-Hamming-sine/CatWindow.R')
#   source('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions/CatBin/CatBin.R')
#   source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/ANOVA/CatPlexi.R')
  #source('E:/R/Cosinor May1-2013/periCosinor.R')     # Add for PC
  library(season)
  functionName<-"CosinorSpan_DateF_PeriVsCosFiltH2test"
  
  if (call==TRUE){      
    header<-F          #These lines are needed to set variables when not run as a function
    #TimeCol<-c(1,2)    ##### for mouse data
    dt<-(0)
    TimeCol<-1
    Y<-2     
    RefDateTime<-"0"              #"200910180000"    for mine: "201302030000" 
    RangeDateTime<-list(Start="0", End="0")
    timeFormat<-"numeric"                   #%Y%m%d%H%M"      #numeric"
    Units<-'Hour'              #  Hour, Day, Week, Year
    Plex<-TRUE
    foldLen<-24
    Progressive<-list(Span=144, Increment=8)            #  Progressive spans of time   144,8
    Period <-list(Set=0,Start=0,Increment=1,End=0)     #  format option:  Set=c(24,26,8)   
    #  tested i .25,e 4,45 (48);  i 1, e 2, 48 (48); i 2 e 2, 12 (12); i 1 e 2, 24 (24); s 40 i 2 e 4, 5 (5); s 40 i 1 e 2, 20 (20)
    Debug<-FALSE
    Colors="BW"       #"terrain"                  #Heat"   #BW
    #terrain.colors(n, alpha = 1)
    #topo.colors(n, alpha = 1)
    Output=list(Txt=F,TxtAmp=F,Doc=T,HeatMap=T,LineGraphs=F)
    
    Graphics<-"pdf"
    Console<-F
    Progressive<-list(Span=132, Increment=8) 
    #timeFormat<-"%Y%m%d%H%M"
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/clgi001.dat'}  #  Add for MAC
    #fileName<-'E:\\R\\CLGi001.pr0'}            # Add for PC
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/FH3h1wk.dat.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/Signal10-20.txt'}
  fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/FWtest/sinesnoneN500--09Oct13--14-03-58.txt'}
  #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/FWtestN15/sinesnoneN15--07Oct13--16-58-55.txt'}
  #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/FWtestN15/FWtestN15missing/sinesnoneN15--07Oct13--16-58-55-miss.txt'}
  ##fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/FWtestN0/FWtestN0-missing/sinesnoneN0--07Oct13--15-26-38-miss.txt'}   
  #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/FWtestN0/sinesnoneN0--07Oct13--15-26-38.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/HanningSignal10-20.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/Data/Good/July03-2013/good-6d-2m-part.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/Data/Good/July03-2013/activity stress c57--stress copy2-part.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/results/reference/FW1/FWedited.txt'}
    #  jaggy  fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Cosinor-Hamming-sine/sinesnone--27Aug13--16-34-43.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Cosinor-Hamming-sine/sineshanning-cos---25Aug13--23-19-37'}
  else {
    # read data
    fileName <- file.choose()
  }
  # rename parameters
  StartDate<-RangeDateTime$Start
  EndDate<-RangeDateTime$End
  Span<-Progressive$Span
  Increment<-Progressive$Increment
  FreqInc<-Period$Increment
  FreqStart<-Period$Start
  FreqEnd<-Period$End
  oneCycle<-Period$Set

  # get filename for display on output 
  if (.Platform$file.sep=="/"){
    m=regexec("[^/]*$",fileName)            #  ./(.$)    pc=[^\\]*$   mac=[^/]*$
  } else {
    m=regexec("[^\\]*$",fileName)
  }
  fileName1<-regmatches(fileName,m)
  
  # send output to file  -- build name of file with path to data f
  BaseTime<-Sys.time()
  thisTime <- format(BaseTime, "--%d%b%y--%H-%M-%S")
  fileName2<-paste(fileName,window,thisTime,"out.txt",sep="")
  fileName3<-paste(fileName,window,thisTime,"out.rtf",sep="")
  if (Output$Txt){
    sink(fileName2, append=FALSE, split=TRUE)
  }
  if (!Console){   # if console is set to off, check the type of output for graphics
      if (Graphics == "pdf"){
        fileName4<-paste(fileName,window,thisTime,"out.pdf",sep="")
        pdf(file=fileName4,width=8, height=10)
      } else {if (Graphics == "jpg"){
                fileName4<-paste(fileName,window,thisTime,"out.jpg",sep="")
                jpg(filename=fileName4,width=8, height=10)
                } else {if (Graphics == "png"){
                          fileName4<-paste(fileName,window,thisTime,"out.png",sep="")
                          png(filename=fileName4,width=8, height=10)
                        }
                }
      }
  }

if (length(TimeCol)>1){
  #for (i in 1:length(TimeCol)){
  #  tableColTypes[i]<-"character"
  #}
  myHeader <- read.table(fileName, header=TRUE, nrows=1, sep="\t",skip=0)
  #get the header for names  -- all strings matching header will be removed
  #if (RepeatedHeaders==1){
  headerChar1 <- substr(names(myHeader)[1],1,1)    # gets the 1st character of the header to be used as a comment indicator
  #}
  #else headerChar1 <- ""               #  use NA as a comment indicator

  MyDataRead1 <- read.table(fileName, header=TRUE, sep="\t",skip=0,stringsAsFactors=FALSE,comment.char=headerChar1,col.names = names(myHeader))
  MyDataRead = na.omit(head(MyDataRead1,n=-2))   # drop the very last row in case it had no data

  if (timeFormat=="numeric"){
    MyDataRead[,TimeCol]<-format(BaseTime + as.numeric(MyDataRead[,TimeCol])*3600,"%Y%m%d%H%M")   # convert to hours, and add to today's date.
    #RefDateTime<-MyDataRead[1,TimeCol]
  }
  #convert time
  MyDataRead[,TimeCol[1]] <- as.POSIXct(strptime(x=paste(MyDataRead[,1],MyDataRead[,2]), format="%d/%m/%y %H:%M:%S", tz="GMT"))
  MyDataRead[,TimeCol[2]] <- format(MyDataRead[,TimeCol[1]],"%Y%m%d%H%M")
  names(MyDataRead)[TimeCol[2]] <- "Datetime"
  TimeCol<-TimeCol[2]
  
  # end TimeCol longer than 1
} else {
  tableColTypes<-c("character","numeric")   #,"numeric","numeric","numeric","character")   # only char, num sometimes
  if (TimeCol>=1 && TimeCol<9) {
    tableColTypes[TimeCol]<-"character"
  } else stop("ERROR:  Are you sure your Time column is > 9?")

  MyDataRead=read.table(fileName,header=header,sep=',',stringsAsFactors=F, colClasses=tableColTypes,blank.lines.skip=TRUE,na.strings=c(" ","--"))
  if (timeFormat=="numeric"){
    MyDataRead[,TimeCol]<-format(BaseTime + as.numeric(MyDataRead[,TimeCol])*3600,"%Y%m%d%H%M")
    #RefDateTime<-format(BaseTime + as.numeric(RefDateTime)*3600,"%Y%m%d%H%M")
  }
  } # end reading for format 2
  
  str(MyDataRead)
  AnalyzeLength<-(as.POSIXct(strptime(tail(MyDataRead[,TimeCol],1), "%Y%m%d%H%M",tz="GMT"))+3600) - as.POSIXct(strptime(MyDataRead[1,TimeCol], "%Y%m%d%H%M",tz="GMT")) 
  MyData_HRs<-(AnalyzeLength)*24  # hours in length of actual data

  if (StartDate == 0){
    StartDate <- MyDataRead[1,TimeCol]      # or should this be like EndDate?  todo
  } else {if (StartDate == 12){
    StartDate <-paste(substr(MyDataRead[1,TimeCol],1,8),"0000",sep="")                #  Use StartTime as start of analysis date-time
  }} #as.POSIXct(strptime(MyData[1,TimeCol], "%Y%m%d",tz="GMT"))
  MyData_length<-length(MyDataRead[,1])

  StartIndex<-which(MyDataRead[,TimeCol]>=StartDate)   #  where is the desired startTime?  (if start point is later than first data point)
  if (EndDate == 0){
    EndDate <- format(as.POSIXct(strptime(tail(MyDataRead[,TimeCol],1), "%Y%m%d%H%M",tz="GMT"))+3600,"%Y%m%d%H%M") # should these be pasted or posix?  todo
    } else {if (EndDate == 12){
    EndDate <-paste(substr(as.numeric(MyDataRead[MyData_length,TimeCol])+as.numeric(10000),1,8),"0000",sep="")                #  Use StartTime as start of analysis date-time
  } }

  EndIndex<-which(MyDataRead[,TimeCol]<=EndDate)   #  where is the desired endTime? 
  cat("Check that your data file and End Date date are correct.  Data file begins:",MyDataRead[1,TimeCol],"; End Date is: ",EndDate,"\n")

  MyData<-MyDataRead[StartIndex[1]:tail(EndIndex,n=1),]     #  grab all the data from array after StartTime, before EndTime
  
  cat("There are ",MyData_HRs," actual hours of data in this file, ",MyDataRead[1,TimeCol]," to ",MyDataRead[tail(EndIndex,n=1),TimeCol],", and ",MyData_length,"data points.\n  Analysis will proceed from ",StartDate," to ",EndDate,"\n")
  
  # convert time
  MyData$time=as.POSIXct(strptime(MyData[,TimeCol], "%Y%m%d%H%M", tz="GMT"))     #   tz="GMT"
  
  # convert time to a number (time in seconds, converted into hours)
  # should probably be done with a hard coded time zone, so CDT and DST don't cause problems

  if (RefDateTime == '0'){
    RefTime <-as.POSIXct(strptime(MyData[1,TimeCol], "%Y%m%d%H%M",tz="GMT"))                #  Use StartTime as reference date-time
    RefTimeString <- MyData[1,TimeCol]
  } else if (RefDateTime==12){
    RefTime<-as.POSIXct(strptime(MyData[1,TimeCol], "%Y%m%d",tz="GMT"))     # midnight of first day of data
    RefTimeString <- paste(substr(MyData[1,TimeCol],1,8),"0000",sep="")
     } else {RefTime<-as.POSIXct(strptime(RefDateTime, "%Y%m%d%H%M",tz="GMT"))
             RefTimeString <- RefDateTime}

  StartTime<-(as.numeric(as.POSIXct(strptime(StartDate, "%Y%m%d%H%M",tz="GMT")))-as.numeric(RefTime))/3600      # convert to hours
  EndTime<-(as.numeric(as.POSIXct(strptime(EndDate, "%Y%m%d%H%M",tz="GMT")))-as.numeric(RefTime))/3600   # convert to hours
  
  MyData_hours<-as.numeric(EndTime-StartTime)           #   get number of hours to analyze
  
  MyData$time.n=as.numeric(MyData$time) - as.numeric(RefTime)
  MyData$time.hour<-MyData$time.n/3600
  MyData_length<-length(MyData[,1])
  #MyData_hours<-(MyData$time.hour[MyData_length]-MyData$time.hour[1])  # hours in length of data if start date is after 1st data point
  
  # calculate number of hours in the full regression (Units*RegressionLen) -- it may not use all of the data
  # this is used for outer loop, full analysis
  #if (Units=='Day'){
  #  MyData_hours<-RegressionLen*24
  #} else if (Units=='Year'){
  #        MyData_hours<-24*365*RegressionLen
  #        } else if (Units=='Week'){
  #                MyData_hours<-24*7*RegressionLen    
  #              }
  cat("The program is using ",MyData_hours," hours for the analysis, starting at hour ",StartTime," relative to RefTime: ",RefTimeString,"\n")
  # calculate number of hours in the Span and Interval (Units*Span, Units*Interval)
  # this is used for inner loop, progressive analysis of intervals over the full data set
  if (Span==0 || Increment==0){     #  || oneCycle[1]>0){     #  No progression -- analyze full dataset
    Span <-MyData_hours
    Increment<-MyData_hours
  } else if (Units=='Hour'){
        Span<-Span
        Increment<-Increment
      } else if (Units=='Day'){
            Span<-Span*24
            Increment<-Increment*24
          } else if (Units=='Year'){
                  Span<-Span*24*365
                  Increment<-Increment*24*365
                } else if (Units=='Week'){
                        Span<-24*7*Span      
                        Increment<-24*7*Increment
                      } else stop(paste("ERROR:  Units is improperly given: ",Units," Valid values:  Hour, Day, Week, Year"))

  if (FreqStart==0){       
    FreqStart <-Span
  } else {if (FreqStart>MyData_hours){        #  validation of FreqStart   (Span chnaged to MyData_hours)
            stop("ERROR:  The parameter Period$Start cannot be larger than Progressive$Span")
          }
          if (FreqStart<0){
            stop("ERROR:  The parameter Period$Start cannot be negative")
          }
      }  # end else FreqStart==0
  #FreqEnd<-FreqStart/(Period$End*FreqInc)
  if (FreqInc==0){
    FreqInc<-1
  }
  if (FreqEnd==0){
    FreqEnd<-4
  }
  cat(FreqStart," FreqStart ",FreqEnd," FreqEnd ",Period$Start,"Period$Start",Span,"Span",Increment,"Increment\n")

  #Variable<-paste(fileName1,":V",Ycol,sep="")
  opar = par()
  par(mar=c(4,4,1,1)) # set up margins
  
  #  #####    note on indexes and variables:  one set tracks through the ACTUAL times and data points:  #####
  #                EndIdx, StartIdx, thisIdxCnt, MyData_length, TimeIdx
  #  #####    another set tracks through the periods, in hours, being calculated:       ######
  #                MyData_hours; StartSpans, Span, Increment, Progression_end, StartTime, StartSpanTime, EndTime
  #  #####    These two must, of course, align. See:   TimeIdx<-which(StartSpanTime <= MyData$time.hour) 
  EndIdx<-0
  # seq(72-84+1,192-50.4,by=8.4)
  if (StartTime==MyData$time.hour[1] && MyData_hours==Span){
    StartSpans<-seq(from=1,to=MyData_hours,by=Increment)        #StartSpans<-seq(1,Span, by=Increment)
  } else {StartSpans<-seq(from=(StartTime),to=(StartTime+MyData_hours-Span),by=Increment)   
          }   #StartSpans<-seq(1,Span, by=Increment)
  print(StartSpans)
  Progression_end<-length(StartSpans)
  Ys_end<-length(Y)
  Page<-0

  if (oneCycle[1]==0){                    #  if oneCycle != 0, FreqEnd and FreqInc are not used.
    if (FreqEnd <= 0 || FreqInc <= 0){
      stop(paste("ERROR:  Period$End (",FreqEnd,") and Period$Increment (",FreqInc,") cannot be 0 when Period$Set is 0"))
    }
    if (FreqStart<FreqEnd){
      stop(paste("ERROR:  The parameter Period$Start (",FreqStart,") cannot be smaller than to Period$End (",FreqEnd,") when Period$Set is 0"))
    }
    if (FreqInc > FreqStart){
      stop(paste("ERROR:  Period$Increment (",FreqInc,") cannot be larger then Period$Start (",FreqStart,") (or Progressive$Span) when Period$Set is 0"))
    }
    RowCnt<-(FreqStart/FreqEnd)/FreqInc       #   (FreqStart-FreqEnd)/FreqInc  #  (Span/2)/FreqInc
  } else {RowCnt <- length(oneCycle)   #  if oneCycle != 0, reset FreqEnd and FreqInc to default=1
          FreqStart <-Span
          FreqInc <-1
          print("resetting freq start and inc")
  }
  
  M <- matrix(data=NA,nrow=RowCnt,ncol=Progression_end)
  PHI <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  PHIr <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  A <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  PR <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  P <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  F <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  mesor_se <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  phi_se <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  amp_se <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  Cycle <- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  hours <-matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  nPts<- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  time<- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)
  newData<- matrix(data=NA,nrow=RowCnt, ncol=Progression_end)    # holds filtered or unfiltered data, myData for each Span

  for (y in 1:Ys_end){
    Ycol<-Y[y]
    #print(Ycol)
    # Use the periodogram
    if (window!="none"){
      CatWindowList<-CatWindow(window=window,myData=MyData[,Ycol],Time=MyData$time.hour,dataN=MyData_hours,Start=MyData$time.hour[1]+StartSpans[1]-1)    # plots the full set of data w/filter
  }
    layout(matrix(c(1,2), 2, 1, byrow = TRUE), 
          widths=c(1), heights=c(1,2))          #   c(figure#1, figure#2), 2 row, 1 col, ...
    par(mar=c(4,4,2,1), oma=c(2,0,1,0))         # set up margins
    if (dt!=0){
      CatPeriodogram<- CatPeri(CatWindowList$data,binsPerHr=1/dt, Hx=.15, cex=.9, Debug=FALSE)    # pass samples/day when units=hrs
    } else {plot.new()}

    n<-length(MyData[,Ycol])
    if (is.numeric(MyData[n, 1])){
      startDateP<-as.POSIXct(strptime(x=MyData[1,1], format="%Y%m%d%H%M", tz="GMT"))
      endDateP<-as.POSIXct(strptime(x=MyData[n,1], format="%Y%m%d%H%M", tz="GMT"))
    } else {startDateP<-MyData[1,1]
            endDateP<-MyData[n,1]}
    title(paste('Start time:',startDateP,';    End time:',endDateP),cex=.7)
    #-------------------
#     if (Plex==TRUE){
#       CatPlexigram<- CatPlex(CatWindowList$data, foldLen=foldLen, Debug=FALSE) 
#     }
    
      cat("\n\tPR\t\t   F\t\t\tP \tSS[j]\t i\t cycle \t  Mesor \t  s.e. \t \t  Amp \t\t s.e. \t \tPhi\t\t s.e.\n")
      #cat("-------------------------------------------------------\n")   
      for (j in 1:Progression_end){   #  make a vector with incremental values.  use var(i) for necessary indexes
      # from:to
        if (j %in% c(1,10)){
          if (j!=1){
            par(mfrow=c(1,1),mar=c(4,4,4,1))
            jht<-2.5
            cexVar<-.5
            htVar<-.3
          } else {jht<-0
              cexVar<-.7
              htVar<-.8}
          Page<-Page+1
          if (oneCycle[1]>0){
            main<-paste("Each Period: Var",y)
            } else {main<-paste("COSINOR Maximum Period: Var",y)}    
          
          plot(0:10, 0:10, type="n",xlab="",ylab="",axes=FALSE, main=main,cex=1)
          text(c(0,.7,1.5,2.3,3.3,4.3,5.3,6.3,7.3,8.3,9.3),c(9.5,9.5,9.5,9.5,9.5,9.5,9.5),labels=c("Span","Period","F","P","PR","Mesor", "s.e.","Amp","s.e.","Phi","s.e."),adj = c(0,0))   #  adj = c(0,0) left justifies
          abline(h=9)
          #browser()
          #page footer
          mtext(paste('Function:',functionName,"  ",fileName1,"; TimeCol=",TimeCol," Ycol=",Ycol, " RefDateTime=",RefDateTime),side=1,line = 1, cex =.5, adj=.9)
          mtext(paste("P",Page,"  ",window,"  ",thisTime," Units=",Units, " Span=",Span, " Increment=",Increment, " header=",header," Set=",Period["Set"]),side=1,line = 2, cex =.5, adj=.9)
        }
          maxAmp = 1                          
          EndSpan<-StartSpans[j]+Span      # 9/30  -1***adj to match gc  Add span length to the last span to get the ending of the span
          
          #browser()
          StartSpanTime<-StartSpans[j]    # 9/30  MyData$time.hour[1]+StartSpans[j]-1
          TimeIdx<-which(StartSpanTime <= MyData$time.hour)   #   get indices past the start of this span
          StartIdx<-TimeIdx[1]                # index of starting time is FIRST index in array of indices
          
          EndSpanTime<-EndSpan        # 9/30 StartTime + EndSpan-1    # EndSpan is # hours to end of this span;  add to starting time
          if (EndSpanTime>EndTime){
            EndSpanTime<-EndTime
          }
        if (EndSpan>EndTime){
          print("**************what to do about this???****************")
          EndSpan<-MyData_hours
        }
          TimeIdx<-which(EndSpanTime >= MyData$time.hour)   #  should be gte;  get indices UP TO the end of this span
          EndIdx<-which.max(TimeIdx)               # index of ending time is LAST index in array if indices
          
          thisIdxCnt<-EndIdx-StartIdx+1   # data points in this span  -- used for S11, and SigmaHat
          Loops<-RowCnt          
          if (oneCycle[1] > 0){              #  a specified period in oneCycle overrides spectrum calculation  (and FreqStart/End?)
            Cycles<-oneCycle
            Loops<-length(Cycles)        
          }
          #cat("StSpan ",StartSpans[j]," Span ",Span," EndSpan ",EndSpan," StrtIdx ",StartIdx, " EndIdx ",EndIdx," thisIdxCnt ",thisIdxCnt," j ",j,"\n")
        if (StartIdx<2 | EndIdx>1370){
          #browser()
        }
        if (window != "none"){
          CatWindowList<-CatWindow(window=window,myData=MyData[StartIdx:EndIdx,Ycol],Time=MyData$time.hour[StartIdx:EndIdx],dataN=Span,Start=StartSpanTime)
          newData<-CatWindowList$data
        }
        else {newData<-MyData[StartIdx:EndIdx,Ycol]}

          for (i in 1:Loops){
            # fit sinusoidal model
            if (oneCycle[1]==0){                  #  if a period has been specified, use present cycle
              #cycle<-Span/(i-(StartSpans[j]-1))       #  divisor should start at one each time this loop restarts
              cycle<-FreqStart/(1+((i-1)*FreqInc))          ####  Span/(1+((i-1)*FreqInc))  from Span/i
              } else cycle<-Cycles[i]
            
            Cycle[i,j]<-cycle                    # store for later 
            hours[i,j] <- paste(StartSpanTime," - ",EndSpanTime,sep="")  # took :59 off because can be decimal hrs;  this shows ALL used
            nPts[i,j] <- paste(StartIdx,"-",EndIdx,"\n(",EndIdx-StartIdx+1,")")
            time[i,j] <- paste(MyData[StartIdx,TimeCol],MyData[EndIdx,TimeCol])
            #browser()
            #  this is for double checking the matrix calculations later.
            #MyData$cosw[1]<-1   # this primes it to accept partial vector values  (??)
            #MyData$sinw[1]<-1   # this primes it to accept partial vector values  (??)
            #MyData$cosw[StartIdx:EndIdx]<-cos(2*pi*MyData$time.hour[StartIdx:EndIdx]/cycle)   
            #MyData$sinw[StartIdx:EndIdx]<-sin(2*pi*MyData$time.hour[StartIdx:EndIdx]/cycle)    
            #model<-glm(V4~cosw+sinw,data=MyData[StartIdx:EndIdx,Ycol])         ####   caution  -- hard coded column  ########
            #s<-summary(model)
            #Amp<-(model$coefficient[2]^2+model$coefficient[3]^2)^.5
            
            #array of parameters
            #MN,             Bcos(2pi/tau)t,               Gsin(2pi/tau)t
            #Mcos(2pi/tau)t, Bcos^2(2pi/tau)t,             Gcos(2pi/tau)t*sin(2pi/tau)t
            #Msin(2pi/tau)t, Bcos(2pi/tau)t*sin(2pi/tau)t, Gsin^2(2pi/tau)t
        
            S11<-thisIdxCnt         # EndIdx - StartIdx +1
            S12<-sum(cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S13<-sum(sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S21<-S12          # sum(cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S22<-sum(cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle)^2)  # change to sin??
            S23<-sum(cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle)*sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S31<-S13          # sum(sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S32<-S23          # sum(cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle)*sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            S33<-sum(sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle)^2)   # used to be =s22
            # build array of parameters for matrix S:   b = Sx
            mdat <- matrix(c(S11,S12,S13, S21,S22,S23,  S31,S32,S33), nrow = 3, ncol=3)
            #crsprd<-crsprd(MyData[1:MyData_length,Ycol],MyData$time.hour[1:MyData_length], 24, mdat)

            #solution for the corresponding dependent variable to matrix above   (vector b, where b=Sx)
            Y11 <- sum(newData)
            Y21 <- sum(newData%*%cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            Y31 <- sum(newData%*%sin(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle))
            #build vector
            mdat2 <- matrix(c(Y11, Y21, Y31), nrow = 3, ncol=1, byrow = FALSE)
            
            #invert matrix to get the solution
            if (det(mdat)<.0000001){
              print("The matrix cannot be inverted")
            }  else{mdatInv <- solve(mdat)
            #mdatInvChol <- chol2inv(chol(mdat))
            
            #multiply the inverted matrix by the dependent variable matrix to get vector M, B, G   (x=inv(S)b)
            coefs <- mdatInv  %*%  mdat2
            
            #crsprd<-crsprd(MyData[StartIdx:EndIdx,Ycol],MyData$time.hour[StartIdx:EndIdx], cycle, mdat)
              
            if (Debug==TRUE || i==Span){
                #print(TimeIdx)
              #print(crsprd)
              #print(s)
              #print(model$coefficients)
              #print(Amp)
              #cat("data22 ",MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle," cycle ",cycle,"\n")
              #cat("cos22 ",cos(MyData$time.hour[StartIdx:EndIdx]*(2*pi)/cycle)," cycle ",cycle,"\n")
              #cat("StartIdx ",StartIdx,"  EndIdx ",EndIdx," thisIdxCnt ",thisIdxCnt,"\n")
                print(mdat)
                print(mdat2)
                #print(mdatInvChol)
                print(mdatInv)
                cat("matrix coefs ",coefs,"\n")
                #browser()         #########   Great Debug location
            }
            
            #sometimes coefs will be undefined.  skip calculations and move to next cycle
            if (!is.na(coefs[2]) && !is.na(coefs[3])){
                #Calculate Amplitude using B and G   (coefs[2]=Beta)
                A[i,j]<-(coefs[2]^2+coefs[3]^2)^0.5
                
                #preserve the index for the cycle with the maximum amplitude
                
                if (A[i,j]>A[maxAmp,j]) {
                  maxAmp<-i
                }
    
                #calculate MESOR
                M[i,j]<-coefs[1]
                #calculate the Mean of Ys
                MeanR<-mean(newData)
                
                # Y(t) = M + bX + gZ    where X=cos(t2pi/cycle) and Z = sin(t2pi/cycle)
                Model_Y = M[i,j] + (coefs[2]*cos(2*pi*MyData$time.hour[StartIdx:EndIdx]/cycle)) + (coefs[3]*sin(2*pi*MyData$time.hour[StartIdx:EndIdx]/cycle))
                # sum(Y-meanY)^2 = sum(Y - Yhat)^2 + sum(Yhat - meanY)^2
                MY_Yhat <- newData-Model_Y
                RSS<-sum(MY_Yhat^2)
                MYhat_Ymean<-Model_Y-MeanR
                MSS<-sum(MYhat_Ymean^2)
                df1<-2
                df2<-thisIdxCnt-3
                F[i,j]<-(MSS/df1)/(RSS/(df2))
                P[i,j]<-1-pf(F[i,j],df1=df1, df2=df2)              # Fisher–Snedecor (F ) (χ2 )
                
                SigmaHat<-(RSS/(df2))^.5
                PR[i,j]<-(MSS/(RSS+MSS))*100
                #cat(thisIdxCnt," sHat ",SigmaHat,"\t",PR[i,j],"\t",F[i,j],"\t ",P[i,j],"\t ")
                cat(thisIdxCnt,"\t",PR[i,j],"\t",F[i,j],"\t ",P[i,j],"\t ")
                
                
                #calculate phi:  artan(-G/B) + Kpi
                ph<-atan(-coefs[3]/coefs[2])
                if (coefs[2]>=0) {phi2<-ph}
                if (coefs[2]<0&coefs[3]>=0) {phi2<-ph+pi}
                if (coefs[2]<0&coefs[3]<0) {phi2<-ph-pi}
                # put in 0 to 2pi range
                PHIr[i,j]<-phi2
                if (phi2<0) { PHIr[i,j]<-phi2+(2*pi)} 
                if (phi2>(2*pi)) { PHIr[i,j]<-phi2-(2*pi)}
                # convert to degrees betwen 0 and 360
                PHI[i,j] <- (PHIr[i,j]/(2*pi))*360
                if (PHI[i,j]>0) {PHI[i,j]<-PHI[i,j]-360}
                
                #calculate standard error for mesor, amplitude, phi -- convert se for phi to degrees
                mesor_se[i,j] <-SigmaHat * mdatInv[1,1]^.5
                amp_se[i,j] <-SigmaHat * (mdatInv[2,2] * cos(PHI[i,j])^2 - (2 * mdatInv[2,3] * cos(PHI[i,j]) * sin(PHI[i,j])) + mdatInv[3,3] * sin(PHI[i,j])^2)^.5
                phi_se[i,j] <- (SigmaHat * (mdatInv[2,2] * sin(PHI[i,j])^2 + (2 * mdatInv[2,3] * cos(PHI[i,j]) * sin(PHI[i,j])) + mdatInv[3,3] * cos(PHI[i,j])^2)^.5)/A[i,j]
                phi_se[i,j]<-phi_se[i,j]*180/pi       # Convert to degrees
                if (Debug==TRUE){
                  cat("sigma ",SigmaHat,"\t",PR[i,j],"\t",F[i,j],"\t ",P[i,j],"\t "," seM ",mesor_se[i,j]," seA ",amp_se[i,j]," sePHI ",phi_se[i,j]," \n")
                }
            }   #  end coefs cannot be calculated
            }   # end matrix cannot be inverted
            cat(StartSpans[j],"\t",i,"\t",format(Cycle[i,j],width=3), "\t ",M[i,j],"\t", format(mesor_se[i,j],digits=8),"\t",A[i,j],"\t",format(amp_se[i,j],digits=8),"\t",format(PHI[i,j],digits=8),"\t",format(phi_se[i,j],digits=8),"\n")
            if (oneCycle[1]>0){   # print this cycle result if  oneCycle parameter set is>0
              ht<-10-(i+(j*htVar))+jht
              print(ht)
              #  prints period and estimates for each period in a range
              text(c(-.25,.8,1.3,2.2,3.2,4.2,5.1,6.2,7.2,8.2,9.2),c(ht,ht,ht,ht,ht,ht,ht,ht,ht,ht,ht),labels=c(paste(StartSpans[j]," - ",format(StartSpans[j]+Span-1,digits=4)),format(Cycle[i,j],digits=4),format(F[i,j],digits=8),format(P[i,j],digits=8),format(PR[i,j],digits=8),format(M[i,j],digits=8), format(mesor_se[i,j],digits=8),format(A[i,j],digits=8),format(amp_se[i,j],digits=8),format(PHI[i,j],digits=8),format(phi_se[i,j],digits=8)),cex=cexVar,adj = c(0,0))
            }
         
          }    #  end i=Loops for loop
          if (oneCycle[1]==0){   # print cycle results here at end if  oneCycle parameter set 0
            ht<-9-(j*htVar)+jht        #8    5, 10, 11, 20, 15, 25
            # prints only the max for each spectrum of frequencies
            text(c(-.25,.8,1.3,2.2,3.1,4.2,5.3,6.3,7.2,8.2,9.2),c(ht,ht,ht,ht,ht,ht,ht,ht,ht,ht,ht),labels=c(paste(StartSpans[j]," - ",format(StartSpans[j]+Span-1,digits=4)),format(Cycle[maxAmp,j],digits=4),format(F[maxAmp,j],digits=6),format(P[i,j],digits=6),format(PR[maxAmp,j],digits=6),format(M[maxAmp,j],digits=6), format(mesor_se[maxAmp,j],digits=6),format(A[maxAmp,j],digits=6),format(amp_se[maxAmp,j],digits=6),format(PHI[maxAmp,j],digits=6),format(phi_se[maxAmp,j],digits=6)),cex=cexVar,adj = c(0,0))
            
          }    #  end oneCycle
      }    #   END for (j in 1:Progression_end){  
  
    
    if (nrow(A)>1 & ncol(A)>1 & Output$HeatMap){
      par(mfrow=c(1,1),mar=c(4,4,3,4))
      #heatmap(MyData$time.hour, A, Rowv = NA, Colv = NA, main = "heatmap")
      
      x <- 1/Cycle[1:(i),1]                 ###F    1/Cycle[1:(i),1] 
      y <- StartSpans+StartTime+(Span/2)      #  10*(1:ncol(A))
      #browser()
      if (Period$Set[1]==0){
        ylabel_string<-paste('Frequency: cycles/hour (',FreqStart,"to",FreqEnd,Units,"in",FreqInc,Units,"Intervals)")
      }else {ylabel_string<-paste('Frequency: cycles/hour (At',Period["Set"],"periods)")
      }
      startDateP<-as.POSIXct(strptime(x=StartDate, format="%Y%m%d%H%M", tz="GMT"))
      endDateP<-as.POSIXct(strptime(x=EndDate, format="%Y%m%d%H%M", tz="GMT"))
      Nterraine<-10
      bwCount<-19    #**  19 for hanning filter;  9 w/o filter
      #Nbw<-gray((0:9)/9)
      Nbw<-gray((0:bwCount)/bwCount)
      #Nbw<-gray(c(0,2/9,4/9,5/9,6/9,7/9,7.5/9,8/9,8.5/9,1))
      #Nbw<-gray(c(0,.25/19,.75/19,1.5/19,2/19,2.75/19,3/19,4/19,5/19,7/19,9/19,10/19,11/19,12/19,13/19,14/19,15/19,16/19,17/19,1))
      #Nbw<-gray(c(0,.1/9,.2/9,.3/9,.5/9,1/9,3/9,5/9,7/9,1))
      #Nbw<-gray(c(0,2/9,4/9,5/9,6/9,6.5/9,7.3/9,7.8/9,8.2/9,1))   too light
      #Nbw<-gray(c(0,1.5/9,2.6/9,3.7/9,4.5/9,5.5/9,6.6/9,7.8/9,1))    too blotchy
      #**Nbw<-gray(c(0,1.2/9,2.4/9,3.6/9,4.3/9,5/9,6/9,7/9,8/9,1))
      HeatMain<-paste("Frequencies across",startDateP,"-",endDateP)
      HeatXlab<-paste(Span,Units,'Intervals, in',Increment,Units,"Increments")
      #**HeatLegend<-seq(from=min(A),to=max(A),length.out=(bwCount+1))
      #cat("A:",max(A)," ",min(A),"\n")
      HeatLegend<-c(0,.16/19,.32/19,.48/19,.64/19,.80/19,.96/19,1.12/19,1.28/19,1.44/19,3/19,5/19,6/19,8/19,10/19,12/19,14/19,16/19,18/19,1)*max(A)
      HeatLegend2<-c(HeatLegend,max(A)*1.1)
      #HeatLegend<-format(HeatLegend2,digits=4)
      if (Colors=="BW"){
        image(y, x, t(A[1:i,]), axes = FALSE, col=rev(Nbw),main=HeatMain,ylab=ylabel_string,xlab=HeatXlab,breaks=HeatLegend2)     #format(max(A)+max(A)*.2,digits=4)))      ###F    fill=rev(Nbw)
        #col controls the colors used in graph;  breaks controls the range of values for each color
        par(xpd=TRUE)  # Do not clip to the drawing area
        lambda <- .025
        legend(par("usr")[2],(par("usr")[4]-par("usr")[3])*.5,xjust = 0, yjust = 0,lwd=3, lty=1, title="Amplitude", legend=format(HeatLegend,digits=4),fill=rev(Nbw),text.width = strwidth("1.00"),cex=.5)                
        #  legend controls the numbers and colors shown on the legend.  No relationship to actual unless same is used.
        #legend("topright", inset=.05, title="Amplitude", legend=HeatLegend,fill=Nbw,y.intersp=.6,text.width = strwidth("1.00"),col="none",cex=.5)
      }else {if (Colors=="Heat"){
        image(y, x, t(A[1:i,]), axes = FALSE, col=rev(heat.colors(32)),main=HeatMain,ylab=ylabel_string,xlab=HeatXlab)      ###F 
        legend("topright", inset=.05, title="Amplitude", legend=HeatLegend,fill=heat.colors(11),y.intersp=.6,text.width = strwidth("1.00"),col="none",cex=.5)
      } else {image(y, x, t(A[1:i,]), axes = FALSE, col=rev(terrain.colors(Nterraine)),main=HeatMain,ylab=ylabel_string,xlab=HeatXlab)      ###F 
              par(xpd=TRUE)  # Do not clip to the drawing area
              lambda <- .025
              legend(par("usr")[2],(par("usr")[4]-par("usr")[3])*.5,xjust = 0, yjust = 0,lwd=3, lty=1, title="Amplitude", legend=HeatLegend,fill=terrain.colors(Nterraine),text.width = strwidth("1.00"),cex=.5)                
      }   
      }#   Colors
      ##op <- par(mar=c(0,0,3,0)+.1)
      #persp(x, y, z, 
      #      theta = 45, phi = 30, 
      #      shade = .5, 
      #      col = rainbow(N), 
      #      border = "green",
      #      main = "perspective plot, theta=45, phi=30")
      #par(op)
      
      #contour(t(A[1:i,]), add = TRUE, drawlabels = FALSE)
      mtext(paste("0 =",RefTime),side=1,line = 3, cex =.7, adj=1)
      #x axis corresponds to row number and the y axis to column number, with column 1 at the bottom, 
      #i.e. a 90 degree counter-clockwise rotation of the conventional printed layout of a matrix.
      axis(1, at = y)                        #  axis(1, at = y+(Span/2)) didn't work!!
      axis(2, at = x)  # 1/Cycle[1:(i),1]
      box()
      #axis(1, 1:7, LETTERS[1:7], col.axis = "blue")
      #pretty(x,n=x/100,min.n=7)
      #X1<-axTicks(1)
      #Y1<-axTicks(2)
      #rug(X1,col= adjustcolor("red", 0.5), lwd = 4)
    }
    
    if (i>1 && Output$LineGraphs==TRUE){
      #par(mfrow=c(6,1),mar=c(2,4,1,1))
      
      layout(matrix(c(1,2,3,4,5,6), 6, 1, byrow = TRUE), 
             widths=c(1), heights=c(1,1,1,1,1,1))          #   c(figure#1, figure#2), 2 row, 1 col, ...
      par(mar=c(2,4,1,1), oma=c(2,0,1,0))         # set up margins
      
      
      if (FreqInc !=1){
        Ylable_inc<- paste("in increments of",FreqInc,"cycles")       
      } else {Ylable_inc <-" "}
      
      if (j>1){              #  J is time span(s) -- progression through span start to ends
        for (k in 1:Loops){   #  i/k is frequency calculations for each time span
          # all cycles repeated, so using only list of cycles from first loop, if more than one loop
          #plot(MyData$time.hour,MyData[,Ycol],type="l",ylab=paste("raw data"),main=paste("Metrics for Variable ",Ycol,"; periods of ",Cycle[k,1],Units, Ylable_inc))
          #window:  MyData[,Ycol] is no longer correct.  how to use newData? (MyData*window)
          #  I think this should use same time spans as in J!!!
          plot(MyData$time.hour,newData,type="l",ylab=paste("data*window"),main=paste("Metrics for Variable ",Ycol,"; periods of ",Cycle[k,1],Units, Ylable_inc))
          cat(k,j,"\n")
          plot(1:j,M[k,],type="l",ylab="MESOR",col=8)
          ampMax<-which.max(A[k,])
          seMax<-which.max(amp_se[k,])
          plot(1:j,A[k,],type="l",ylab="Amplitude",col=4,ylim=c(0,(A[k,ampMax]+amp_se[k,seMax])))
          points(1:j,(A[k,]+amp_se[k,]),type="p",pch=20,cex=.1,axes=F,col=3,ylim=c(-360,0))   
          points(1:j,(A[k,]-amp_se[k,]),type="p",pch=20,cex=.1,axes=F,col=3,ylim=c(-360,0))
          #lines(A[1,]+M[1,],type="l")
          plot(1:j,PHI[k,],type="l",ylab="Acrophase",col=6,ylim=c(-360,0))
          #par(new=T)
          #plot(1:j,PHI[k,]+phi_se[k,],type="p",pch=20,axes=F,col=3)   #   what is wrong here?
          #par(new=F)
          points(1:j,(PHI[k,]+phi_se[k,]),type="p",pch=20,cex=.2,axes=F,col=3)   
          points(1:j,(PHI[k,]-phi_se[k,]),type="p",pch=20,cex=.2,axes=F,col=3)   
          plot(1:j,PR[k,],type="l",ylab="Acrophase",col=6) 
          #browser()  #  what does phi + phi-se look like?
          
          plot(1:j,P[k,],type="l",ylab="P Value",col=9,ylim=c(0,.6))
          abline(h=.5,lty="dashed")
          
          #browser()     #  if progressive, plot(1:j, X[k,]);   otherwise, plot(1:i,X[k,])  except variable always w/time
          # http://cran.r-project.org/doc/contrib/Lemon-kickstart/kr_addat.html
        }       # end K to Loops
      }  else {                   # end if j>1
        CycleLen<-length(Cycle)
        cat("cycle",CycleLen)
        if (CycleLen>6){    #   if Cycle = 0 there is a long sequence, otherwise only a few
          Ylable<- paste("Metrics for Variable ",Ycol,": periods of ",Cycle[i],' to ',Cycle[1],Units, Ylable_inc)
        } else {
          Ylable<- paste("Metrics for Variable ",Ycol,": periods of ",list(Cycle[]),Units, Ylable_inc)
        }
        #plot(MyData$time.hour,MyData[,Ycol],type="l",ylab=paste("raw data"),main=Ylable)
        #window:  maybe this is OK, since only 1 timespan (j=1).  MyData[,Ycol] is no longer correct.  how to use newData? (MyData*window)
        plot(MyData$time.hour,newData,type="l",ylab=paste("data*window"),main=Ylable)
        plot(1/Cycle[CycleLen:1],M[CycleLen:1],type="l",ylab='MESOR',col=8)
        #ampMax<-which.max(A[k,])
        #seMax<-which.max(amp_se[k,])
        plot(1/Cycle[CycleLen:1],A[CycleLen:1],type="l",ylab="Amplitude",col=4)    #,ylim=c(0,(A[]+amp_se[])))
        points(1/Cycle[CycleLen:1],(A[CycleLen:1]+amp_se[CycleLen:1]),type="p",pch=20,cex=.6,axes=F,col=3)   #,ylim=c(-360,0))   
        points(1/Cycle[CycleLen:1],(A[CycleLen:1]-amp_se[CycleLen:1]),type="p",pch=20,cex=.6,axes=F,col=3)   #,ylim=c(-360,0))
        #lines(A[1,]+M[1,],type="l")
        plot(1/Cycle[CycleLen:1],PHI[CycleLen:1],type="l",ylab="Acrophase",col=6,ylim=c(-360,0))
        #par(new=T)
        #plot(Cycle[],PHI[k,]+phi_se[k,],type="p",pch=20,axes=F,col=3)   #   what is wrong here?
        #par(new=F)
        points(1/Cycle[CycleLen:1],(PHI[CycleLen:1]+phi_se[CycleLen:1]),type="p",pch=20,cex=.6,axes=F,col=3)   
        points(1/Cycle[CycleLen:1],(PHI[CycleLen:1]-phi_se[CycleLen:1]),type="p",pch=20,cex=.6,axes=F,col=3)   
        plot(1/Cycle[CycleLen:1],PR[CycleLen:1],type="l",ylab="Percent Rhythm",col=6) 
        #browser()  #  what does phi + phi-se look like?
        
        plot(1/Cycle[CycleLen:1],P[CycleLen:1],type="l",ylab="P Value",col=9,ylim=c(0,.6))
        abline(h=.5,lty="dashed")

        #}       # end K to Loops
      }  #  end else if j=1
      mtext("Green dots = S.E. standard error",side=1,line = 2, cex =.8, adj=.7,col=3)
    } # end if i>1 and LineGraphs == T
    #View(mat)
    
  
    if(Output$Doc){
      library(rtf)
      output<-fileName3
      rtf<-RTF(output,width=11,height=8.5,font.size=10,omi=c(1,1,1,1))
      addParagraph(rtf,paste(fileName3,"\n  TimeCol=",TimeCol,",  Ycol=",Ycol, ",  header=",header,"\n --  Periods=",Period["Set"],", Units=",Units, ",  Span=",Span, ",  Increment=",Increment, "\nFreqStart=",FreqStart, ",  FreqInc=",FreqInc, ",  FreqEnd=",FreqEnd, "\nRefDateTime=",RefDateTime, ", StartTime=",StartTime,", EndTime=",EndTime,"\n"))
      mat<-data.frame(matrix(c(time,hours,nPts,Cycle,PR,P,M,mesor_se,A,amp_se,PHI,phi_se),ncol=12))  #,dimnames=list(row_names,colName))
      names(mat)<-c("Time Pts","Hours from RefDateTime","#Pts","Period in Hrs","PR=MSS/ (RSS+MSS)","P","Mesor","Mesor SE","Amp","Amp SE","PHI","PHI SE") # format column names
  
      addTable(rtf,mat,font.size=9,row.names=FALSE,NA.string="--")
      done(rtf)                    # writes and closes the file
    }    # end RTF
  }    #    END for (y in 1:Ys_end){
  if (Output$Txt){
    sink()
  }
  if (Output$TxtAmp){
    filename<-cat(fileName2,"amp")
    sink(fileName2, append=FALSE, split=TRUE)
    print(A[i])
    sink()
  }
  
  if (!Console){
    print(paste("Output has been saved to:",fileName4))
    dev.off()
  }

par(opar)
}
